@@ -1,17 +1,19 @@
 #!/usr/bin/env perl
-#example for showing the laziness of attributes
+# repetitive calculation of the average vector length for a sphere of random vectors
+# shows capabilities of using MCE to use multiple cores.
 use Modern::Perl;
 use Math::Vector::Real;
 use Math::Vector::Real::Random;
+use MCE::Map; #carry out the map using the many core engine
 use Time::HiRes qw(time);
 
 my $t1   = time;
-my @avg  = map { 
+my @avg  = mce_map { 
                  my @mvrs = &gen_mvr_sphere;
                  my $sum = 0;
                  $sum += abs($_) foreach @mvrs;
                  $sum/(scalar(@mvrs)) 
-               } 0 .. 100;
+               } 0 .. 1000;
 
 say foreach @avg;
 
